@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -36,7 +36,7 @@
 
 /**
  * Structure for Alert-Info headers.
- * @defvar osip_alert_info_t
+ * @var osip_alert_info_t
  */
   typedef osip_call_info_t osip_alert_info_t;
 
@@ -54,7 +54,7 @@ extern "C"
  * Free a Alert-Info element.
  * @param header The element to work on.
  */
-#define  osip_alert_info_free(header)      osip_call_info_free(header)
+#define  osip_alert_info_free      osip_call_info_free
 /**
  * Parse a Alert-Info element.
  * @param header The element to work on.
